@@ -15,11 +15,15 @@ function(x)
     if(x@windows > 1) par(mar=c(0,4,3,3))
   }
 
+  #layout(matrix(c(2,3,4,5,1,1,1,1),nc=4,byrow=TRUE),c(1,1,1,1),c(1,2),FALSE)
+  #layout(matrix(c(1,2,1,3,1,4,1,5),nc=2,byrow=TRUE),c(5,1),c(1),FALSE)
+
+
+
   x.range <- 1:(x@xrange[2]*x@spacing)
   y.range <- seq(x@yrange[1],x@yrange[2],length.out=length(x.range))
  
   # get current values of series to be charted
-  xx <- eval(x@passed.args$x)
   xx <- x@xdata
 
 #  if(!is.xts(xx)) xx <- as.xts(xx)
@@ -169,7 +173,7 @@ function(x)
   # draw the final x labels
   #title(xlab=x@colors$time.scale,col.lab=x@colors$fg.col)
   if(x@minor.ticks)
-    axis(1,at=1:x@length*x@spacing+1,labels=FALSE,col=x@colors$minor.tick)
+    axis(1,at=x.pos,labels=FALSE,col=x@colors$minor.tick)
  
   axis(1,at=x@bp*x@spacing+1,labels=x@x.labels,las=1,lwd=1,mgp=c(3,2,0),
        col=x@colors$major.tick)
